@@ -146,4 +146,4 @@ def standalone_deserialize_metamake_from_makefile(makefile_filename):
             subfile.close()
     
     # add the temp import dir to the system path
-    sys.path.append(temp_metamake_import_path)
+    sys.path.insert(0, temp_metamake_import_path)
