@@ -1,4 +1,5 @@
 import platform
+import warnings
 from metamake._flags import Flag
 from metamake._path import loggable_path
 from metamake._shell import shell
@@ -24,6 +25,8 @@ class Dependency(object):
     
     def __init__(self, url, path, build_cmd=None, clean_cmd=None):
 
+        warnings.warn("Dependency objects are deprecated, please use your own custom dependency tracking", DeprecationWarning)
+        
         self.__url = url
         self.__path = path
 
